# i18n-lib

[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
![GitHub License](https://img.shields.io/github/license/HamletSargsyan/i18n-lib)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/HamletSargsyan/i18n-lib)
![PyPI - Downloads](https://img.shields.io/pypi/dm/i18n-lib)
![PyPI - Version](https://img.shields.io/pypi/v/i18n-lib)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/i18n-lib)
![Lint](https://github.com/HamletSargsyan/i18n-lib/actions/workflows/lint.yml/badge.svg)
![Tests](https://github.com/HamletSargsyan/i18n-lib/actions/workflows/tests.yml/badge.svg)
![Documentation](https://github.com/HamletSargsyan/i18n-lib/actions/workflows/documentation.yml/badge.svg)

## install

### from PyPI

```bash
pip install i18n-lib
```

### from source

```bash
pip install git+https://github.com/HamletSargsyan/i18n-lib.git
```

## License

This project is licensed under the [MIT License](https://github.com/HamletSargsyan/i18n-lib/blob/main/LICENSE).
